@@ -2,21 +2,15 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Noter",
-    "New note" : "Ny note",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
-    "_%n word_::_%n words_" : ["%n ord","%n ord"],
     "The last viewed note cannot be accessed. " : "Den senest viste note kan ikke tilgås.",
     "The notes folder is not accessible: %s" : "Mappen med noter er ikke tilgængelig: %s",
-    "File error" : "Fejl i fil",
     "Encryption Error" : "Fejl i kryptering",
     "Error" : "Fejl",
-    "No notes found" : "Ingen noter fundet",
-    "Delete note" : "Slet note",
-    "Favorite" : "Foretrukken",
+    "New note" : "Ny note",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
     "Settings" : "Indstillinger",
-    "The note has unsaved changes." : "Noten har ikke gemte ændringer.",
-    "Click here to try again" : "Klik her for at prøve igen",
+    "Delete note" : "Slet note",
     "Saving failed!" : "Kunne ikke gemme!",
-    "Note saved" : "Note gemt"
+    "_%n word_::_%n words_" : ["%n ord","%n ord"]
 },
 "nplurals=2; plural=(n != 1);");
