@@ -3,19 +3,12 @@ OC.L10N.register(
     {
     "Notes" : "Notas",
     "The last viewed note cannot be accessed. " : "No se puede acceder a la última nota consultada. ",
-    "New note" : "Nota nueva",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
-    "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
-    "File error" : "Error de archivo",
     "Encryption Error" : "Error de encripción",
     "Error" : "Error",
+    "New note" : "Nota nueva",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
     "Delete note" : "Borrar nota",
-    "Favorite" : "Favorito",
-    "No notes found" : "No se encontraron notas",
-    "The note has unsaved changes." : "La nota contiene cambios sin guardar",
-    "*" : "*",
-    "Click here to try again" : "Haz click aquí para intentarlo de nuevo",
     "Saving failed!" : "¡Falla al guardar!",
-    "Note saved" : "Nota guardada"
+    "_%n word_::_%n words_" : ["%n palabra","%n palabras"]
 },
 "nplurals=2; plural=(n != 1);");
