@@ -15,6 +15,12 @@ OC.L10N.register(
     "File extension for new notes" : "סיומת קובץ לפתקיות חדשות",
     "All notes" : "כל הפתקים",
     "Categories" : "קטגוריות",
+    "Today" : "היום",
+    "Yesterday" : "אתמול",
+    "This week" : "השבוע",
+    "This month" : "החודש",
+    "Remove from favorites" : "הסרה מהמועדפים",
+    "Add to favorites" : "הוספה למועדפים",
     "Delete note" : "מחיקת הערה",
     "Category" : "קטגוריה",
     "Uncategorized" : "ללא קטגוריה",
