@@ -3,14 +3,15 @@ OC.L10N.register(
     {
     "Notes" : "Jegyzetek",
     "The last viewed note cannot be accessed. " : "Az utoljára megtekintett jegyzet nem elérhető.",
-    "The notes folder is not accessible: %s" : "A jegyzetek mappa nem elérhető: %s",
+    "The notes folder is not accessible: %s" : "A jegyzetek mappa nem érhető el: %s",
     "Encryption Error" : "Titkosítási hiba",
     "Error" : "Hiba",
     "New note" : "Új jegyzet",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "Mentetlen jegyzetek vannak. Az oldal elhagyásával a változások elvesznek!",
+    "Distraction-free notes and writing" : "Figyelemelterelés nélküli jegyzetelés és írás",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "Mentetlen jegyzetek vannak. Az oldal elhagyásával a változások elvesznek.",
     "Settings" : "Beállítások",
     "Folder to store your notes" : "A jegyzetek tárolási mappája",
-    "path to notes" : "Megjegyzés útvonala",
+    "path to notes" : "megjegyzések útvonala",
     "File extension for new notes" : "Fájlkiterjesztés új jegyzetekhez",
     "All notes" : "Összes jegyzet",
     "Categories" : "Kategóriák",
@@ -28,7 +29,6 @@ OC.L10N.register(
     "Details" : "Részletek",
     "Preview" : "Előnézet",
     "Edit" : "Szerkesztés",
-    "Fullscreen" : "Teljes képernyő",
     "Set category" : "Kategória beállítása",
     "Category" : "Kategória",
     "Uncategorized" : "Kategorizálatlan",
