@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "Նոթեր",
     "New note" : "Նոր նոթ",
-    "_%n word_::_%n words_" : ["%n բառ","%n բառ"],
-    "Delete note" : "Ջնջել նոթը"
+    "Delete note" : "Ջնջել նոթը",
+    "_%n word_::_%n words_" : ["%n բառ","%n բառ"]
 },
 "nplurals=2; plural=(n != 1);");
