@@ -3,9 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "Notas",
     "New note" : "Nove nota",
-    "_%n word_::_%n words_" : ["%n parola","%n parolas"],
     "Delete note" : "Dele nota",
-    "Favorite" : "Favoritar",
-    "No notes found" : "Nulle notas trovate"
+    "_%n word_::_%n words_" : ["%n parola","%n parolas"]
 },
 "nplurals=2; plural=(n != 1);");
