@@ -3,9 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "Catatan",
     "New note" : "Catatan baru",
-    "_%n word_::_%n words_" : ["%n kata"],
     "Delete note" : "Hapus catatan",
-    "Favorite" : "Favorit",
-    "No notes found" : "Catatan tidak ditemukan"
+    "_%n word_::_%n words_" : ["%n kata"]
 },
 "nplurals=1; plural=0;");
