@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Notes" : "Белешки",
     "New note" : "Нова белешка",
+    "Settings" : "Параметри",
+    "Add to favorites" : "Додади во фаворити",
     "Delete note" : "Избриши белешка",
     "_%n word_::_%n words_" : ["%n збор","%n зборови"]
 },
