@@ -3,9 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "Notas",
     "New note" : "Nova nota",
-    "_%n word_::_%n words_" : ["%n palavra","%n palavras"],
     "Delete note" : "Apagar nota",
-    "Favorite" : "Favorita",
-    "No notes found" : "Não foram encontradas notas"
+    "_%n word_::_%n words_" : ["%n palavra","%n palavras"]
 },
 "nplurals=2; plural=(n != 1);");
