@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Notes" : "บันทึกย่อ",
     "New note" : "สร้างบันทึกใหม่",
-    "_%n word_::_%n words_" : ["%n คำ"],
-    "Delete note" : "ลบบันทึกย่อ"
+    "Delete note" : "ลบบันทึกย่อ",
+    "_%n word_::_%n words_" : ["%n คำ"]
 },
 "nplurals=1; plural=0;");
